@@ -8,10 +8,10 @@
 #include "job.h"
 #include "private/protocol_p.h"
 #include "session_p.h"
-
 #include <QCoreApplication>
+#include <QRandomGenerator>
 #include <QTimer>
-
+using namespace std::chrono_literals;
 class FakeSessionPrivate : public SessionPrivate
 {
 public:
@@ -30,7 +30,7 @@ public:
         if (!id.isEmpty()) {
             sessionId = id;
         } else {
-            sessionId = QCoreApplication::instance()->applicationName().toUtf8() + '-' + QByteArray::number(qrand());
+            sessionId = QCoreApplication::instance()->applicationName().toUtf8() + '-' + QByteArray::number(QRandomGenerator::global()->bounded(1, RAND_MAX));
         }
 
         connected = false;
@@ -48,7 +48,7 @@ public:
         }
 
         // Like Session does: delay the actual disconnect+reconnect
-        QTimer::singleShot(10, q_ptr, [&]() {
+        QTimer::singleShot(10ms, q_ptr, [&]() {
             socketDisconnected();
             Q_EMIT q_ptr->reconnected();
             connected = true;
